@@ -48,7 +48,7 @@ DialogEditTask::DialogEditTask(QWidget *parent) :
     if (!calendar){
         cout << "Error retrieving default Calendar" << endl;
     }
-    QString calendarText = calendar->getCalendarName().c_str();
+    QString calendarText = QString::fromLocal8Bit(calendar->getCalendarName().c_str());
     this->ui->buttonCalendar->setValueText(calendarText);
     this->calendarPickSelector->setCalendarId(calendar->getCalendarId());
 
@@ -90,9 +90,9 @@ void DialogEditTask::loadComponent(){
         return;
     }
 
-    ui->editSummary->setText(todo->getSummary().c_str());
+    ui->editSummary->setText(QString::fromLocal8Bit(todo->getSummary().c_str()));
     ui->checkDone->setChecked(QVariant(todo->getStatus()).toBool());
-    ui->textDescription->setText(todo->getDescription().c_str());
+    ui->textDescription->setText(QString::fromLocal8Bit(todo->getDescription().c_str()));
 
     QDateTime dueDateTime;
     dueDateTime.setTime_t(todo->getDue());
@@ -138,7 +138,7 @@ bool DialogEditTask::getTodo(){
         cout << "Error retrieving Calendar" << endl;
         return false;
     }
-    QString calendarText = calendar->getCalendarName().c_str();
+    QString calendarText = QString::fromLocal8Bit(calendar->getCalendarName().c_str());
     this->ui->buttonCalendar->setValueText(calendarText);
     this->calendarPickSelector->setCalendarId(cal_id);
 
