@@ -45,7 +45,7 @@ DialogNoteEdit::DialogNoteEdit(QWidget *parent) :
     if (!calendar){
         cout << "Error retrieving default Calendar" << endl;
     }
-    QString calendarText = calendar->getCalendarName().c_str();
+    QString calendarText = QString::fromLocal8Bit(calendar->getCalendarName().c_str());
     this->ui->buttonCalendar->setValueText(calendarText);
     this->calendarPickSelector->setCalendarId(calendar->getCalendarId());
 
@@ -108,7 +108,7 @@ bool DialogNoteEdit::getJournal(){
         cout << "Error retrieving Calendar" << endl;
         return false;
     }
-    QString calendarText = calendar->getCalendarName().c_str();
+    QString calendarText = QString::fromLocal8Bit(calendar->getCalendarName().c_str());
     this->ui->buttonCalendar->setValueText(calendarText);
     this->calendarPickSelector->setCalendarId(cal_id);
 
